# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProject(BaseModel):
    update_project: Optional["UpdateProjectUpdateProject"] = Field(
        alias="updateProject"
    )


class UpdateProjectUpdateProject(BaseModel):
    id: str
    name: str


UpdateProject.model_rebuild()
