# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalDrugClass(BaseModel):
    update_medical_drug_class: Optional[
        "UpdateMedicalDrugClassUpdateMedicalDrugClass"
    ] = Field(alias="updateMedicalDrugClass")


class UpdateMedicalDrugClassUpdateMedicalDrugClass(BaseModel):
    id: str
    name: str


UpdateMedicalDrugClass.model_rebuild()
