# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class WorkflowExists(BaseModel):
    workflow_exists: Optional["WorkflowExistsWorkflowExists"] = Field(
        alias="workflowExists"
    )


class WorkflowExistsWorkflowExists(BaseModel):
    result: Optional[bool]


WorkflowExists.model_rebuild()
